function rotMat = rotx(angleDeg)
    % ROTX Rotation matrix about X-axis
    % -----
    %
    % Syntax:
    %   rotMat = rotx(angleDeg) returns the rotation matrix that rotates
    %   a point of an angle `angleDeg` (in degrees) around the X-axis.
    %
    % Inputs:
    %   angleDeg: Angle of rotation, [deg]
    %
    % Outputs:
    %   rotMat  : 3x3 matrix for the rotation around X-axis
    %
    % See also: roty, rotz.
    %
    % <a href="https://gitlab.uliege.be/rotare/documentation">Complete documentation (online)</a>

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2023 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/rotare/rotare
    % Docs: https://gitlab.uliege.be/rotare/documentation
    % Issues: https://gitlab.uliege.be/rotare/rotare/-/issues
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    validateattributes(angleDeg, {'numeric'}, {'scalar'}, mfilename(), 'angleDeg', 1);

    rotMat = [1,              0,              0
              0,              cosd(angleDeg), -sind(angleDeg)
              0,              sind(angleDeg), cosd(angleDeg)];

end
